@@ -1,6 +1,6 @@
 package GeoIP2::Error::Generic;
 {
-  $GeoIP2::Error::Generic::VERSION = '0.0100';
+  $GeoIP2::Error::Generic::VERSION = '0.0200';
 }
 
 use strict;
@@ -26,16 +26,16 @@ GeoIP2::Error::Generic - A generic exception
 
 =head1 VERSION
 
-version 0.0100
+version 0.0200
 
 =head1 SYNOPSIS
 
   use 5.008;
 
-  use GeoIP2::Webservice::Client;
+  use GeoIP2::WebService::Client;
   use Scalar::Util qw( blessed );
 
-  my $client = GeoIP2::Webservice::Client->new(
+  my $client = GeoIP2::WebService::Client->new(
       user_id     => 42,
       license_key => 'abcdef123456',
   );
