@@ -1,6 +1,6 @@
 package GeoIP2::Record::Location;
 {
-  $GeoIP2::Record::Location::VERSION = '0.0100';
+  $GeoIP2::Record::Location::VERSION = '0.0200';
 }
 
 use strict;
@@ -66,15 +66,15 @@ GeoIP2::Record::Location - Contains data for the location record associated with
 
 =head1 VERSION
 
-version 0.0100
+version 0.0200
 
 =head1 SYNOPSIS
 
   use 5.008;
 
-  use GeoIP2::Webservice::Client;
+  use GeoIP2::WebService::Client;
 
-  my $client = GeoIP2::Webservice::Client->new(
+  my $client = GeoIP2::WebService::Client->new(
       user_id     => 42,
       license_key => 'abcdef123456',
   );
